# pyartifactsmmo

Artifacts is an API-based MMO game where you can manage 5 characters to explore, fight, gather resources, craft items and much more.

Website: <https://artifactsmmo.com/>

Documentation: <https://docs.artifactsmmo.com/>

OpenAPI Spec: <https://api.artifactsmmo.com/openapi.json>

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.6
- Package version: 1.0.1
- Generator version: 7.8.0-SNAPSHOT
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements

Python 3.7+

## Installation & Usage

### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```

(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:

```python
import pyartifactsmmo
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```

(or `sudo python setup.py install` to install the package for all users)

Then import the package:

```python
import pyartifactsmmo
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import pyartifactsmmo
from pyartifactsmmo.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = pyartifactsmmo.Configuration(
    host = "http://localhost"
)



# Enter a context with an instance of the API client
async with pyartifactsmmo.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = pyartifactsmmo.AccountsApi(api_client)
    add_account_schema = pyartifactsmmo.AddAccountSchema() # AddAccountSchema | 

    try:
        # Create Account
        api_response = await api_instance.create_account_accounts_create_post(add_account_schema)
        print("The response of AccountsApi->create_account_accounts_create_post:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AccountsApi->create_account_accounts_create_post: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *<http://localhost>*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccountsApi* | [**create_account_accounts_create_post**](docs/AccountsApi.md#create_account_accounts_create_post) | **POST** /accounts/create | Create Account
*CharactersApi* | [**create_character_characters_create_post**](docs/CharactersApi.md#create_character_characters_create_post) | **POST** /characters/create | Create Character
*CharactersApi* | [**delete_character_characters_delete_post**](docs/CharactersApi.md#delete_character_characters_delete_post) | **POST** /characters/delete | Delete Character
*CharactersApi* | [**get_all_characters_characters_get**](docs/CharactersApi.md#get_all_characters_characters_get) | **GET** /characters/ | Get All Characters
*CharactersApi* | [**get_character_characters_name_get**](docs/CharactersApi.md#get_character_characters_name_get) | **GET** /characters/{name} | Get Character
*EventsApi* | [**get_all_events_events_get**](docs/EventsApi.md#get_all_events_events_get) | **GET** /events/ | Get All Events
*GrandExchangeApi* | [**get_all_ge_items_ge_get**](docs/GrandExchangeApi.md#get_all_ge_items_ge_get) | **GET** /ge/ | Get All Ge Items
*GrandExchangeApi* | [**get_ge_item_ge_code_get**](docs/GrandExchangeApi.md#get_ge_item_ge_code_get) | **GET** /ge/{code} | Get Ge Item
*ItemsApi* | [**get_all_items_items_get**](docs/ItemsApi.md#get_all_items_items_get) | **GET** /items/ | Get All Items
*ItemsApi* | [**get_item_items_code_get**](docs/ItemsApi.md#get_item_items_code_get) | **GET** /items/{code} | Get Item
*MapsApi* | [**get_all_maps_maps_get**](docs/MapsApi.md#get_all_maps_maps_get) | **GET** /maps/ | Get All Maps
*MapsApi* | [**get_map_maps_xy_get**](docs/MapsApi.md#get_map_maps_xy_get) | **GET** /maps/{x}/{y} | Get Map
*MonstersApi* | [**get_all_monsters_monsters_get**](docs/MonstersApi.md#get_all_monsters_monsters_get) | **GET** /monsters/ | Get All Monsters
*MonstersApi* | [**get_monster_monsters_code_get**](docs/MonstersApi.md#get_monster_monsters_code_get) | **GET** /monsters/{code} | Get Monster
*MyAccountApi* | [**change_password_my_change_password_post**](docs/MyAccountApi.md#change_password_my_change_password_post) | **POST** /my/change_password | Change Password
*MyAccountApi* | [**get_bank_golds_my_bank_gold_get**](docs/MyAccountApi.md#get_bank_golds_my_bank_gold_get) | **GET** /my/bank/gold | Get Bank Golds
*MyAccountApi* | [**get_bank_items_my_bank_items_get**](docs/MyAccountApi.md#get_bank_items_my_bank_items_get) | **GET** /my/bank/items | Get Bank Items
*MyCharactersApi* | [**action_accept_new_task_my_name_action_task_new_post**](docs/MyCharactersApi.md#action_accept_new_task_my_name_action_task_new_post) | **POST** /my/{name}/action/task/new | Action Accept New Task
*MyCharactersApi* | [**action_complete_task_my_name_action_task_complete_post**](docs/MyCharactersApi.md#action_complete_task_my_name_action_task_complete_post) | **POST** /my/{name}/action/task/complete | Action Complete Task
*MyCharactersApi* | [**action_crafting_my_name_action_crafting_post**](docs/MyCharactersApi.md#action_crafting_my_name_action_crafting_post) | **POST** /my/{name}/action/crafting | Action Crafting
*MyCharactersApi* | [**action_delete_item_my_name_action_delete_post**](docs/MyCharactersApi.md#action_delete_item_my_name_action_delete_post) | **POST** /my/{name}/action/delete | Action Delete Item
*MyCharactersApi* | [**action_deposit_bank_gold_my_name_action_bank_deposit_gold_post**](docs/MyCharactersApi.md#action_deposit_bank_gold_my_name_action_bank_deposit_gold_post) | **POST** /my/{name}/action/bank/deposit/gold | Action Deposit Bank Gold
*MyCharactersApi* | [**action_deposit_bank_my_name_action_bank_deposit_post**](docs/MyCharactersApi.md#action_deposit_bank_my_name_action_bank_deposit_post) | **POST** /my/{name}/action/bank/deposit | Action Deposit Bank
*MyCharactersApi* | [**action_equip_item_my_name_action_equip_post**](docs/MyCharactersApi.md#action_equip_item_my_name_action_equip_post) | **POST** /my/{name}/action/equip | Action Equip Item
*MyCharactersApi* | [**action_fight_my_name_action_fight_post**](docs/MyCharactersApi.md#action_fight_my_name_action_fight_post) | **POST** /my/{name}/action/fight | Action Fight
*MyCharactersApi* | [**action_gathering_my_name_action_gathering_post**](docs/MyCharactersApi.md#action_gathering_my_name_action_gathering_post) | **POST** /my/{name}/action/gathering | Action Gathering
*MyCharactersApi* | [**action_ge_buy_item_my_name_action_ge_buy_post**](docs/MyCharactersApi.md#action_ge_buy_item_my_name_action_ge_buy_post) | **POST** /my/{name}/action/ge/buy | Action Ge Buy Item
*MyCharactersApi* | [**action_ge_sell_item_my_name_action_ge_sell_post**](docs/MyCharactersApi.md#action_ge_sell_item_my_name_action_ge_sell_post) | **POST** /my/{name}/action/ge/sell | Action Ge Sell Item
*MyCharactersApi* | [**action_move_my_name_action_move_post**](docs/MyCharactersApi.md#action_move_my_name_action_move_post) | **POST** /my/{name}/action/move | Action Move
*MyCharactersApi* | [**action_recycling_my_name_action_recycling_post**](docs/MyCharactersApi.md#action_recycling_my_name_action_recycling_post) | **POST** /my/{name}/action/recycling | Action Recycling
*MyCharactersApi* | [**action_task_exchange_my_name_action_task_exchange_post**](docs/MyCharactersApi.md#action_task_exchange_my_name_action_task_exchange_post) | **POST** /my/{name}/action/task/exchange | Action Task Exchange
*MyCharactersApi* | [**action_unequip_item_my_name_action_unequip_post**](docs/MyCharactersApi.md#action_unequip_item_my_name_action_unequip_post) | **POST** /my/{name}/action/unequip | Action Unequip Item
*MyCharactersApi* | [**action_withdraw_bank_gold_my_name_action_bank_withdraw_gold_post**](docs/MyCharactersApi.md#action_withdraw_bank_gold_my_name_action_bank_withdraw_gold_post) | **POST** /my/{name}/action/bank/withdraw/gold | Action Withdraw Bank Gold
*MyCharactersApi* | [**action_withdraw_bank_my_name_action_bank_withdraw_post**](docs/MyCharactersApi.md#action_withdraw_bank_my_name_action_bank_withdraw_post) | **POST** /my/{name}/action/bank/withdraw | Action Withdraw Bank
*MyCharactersApi* | [**get_all_characters_logs_my_logs_get**](docs/MyCharactersApi.md#get_all_characters_logs_my_logs_get) | **GET** /my/logs | Get All Characters Logs
*MyCharactersApi* | [**get_my_characters_my_characters_get**](docs/MyCharactersApi.md#get_my_characters_my_characters_get) | **GET** /my/characters | Get My Characters
*ResourcesApi* | [**get_all_resources_resources_get**](docs/ResourcesApi.md#get_all_resources_resources_get) | **GET** /resources/ | Get All Resources
*ResourcesApi* | [**get_resource_resources_code_get**](docs/ResourcesApi.md#get_resource_resources_code_get) | **GET** /resources/{code} | Get Resource
*TokenApi* | [**generate_token_token_post**](docs/TokenApi.md#generate_token_token_post) | **POST** /token/ | Generate Token
*DefaultApi* | [**get_status_get**](docs/DefaultApi.md#get_status_get) | **GET** / | Get Status

## Documentation For Models

- [ActionItemBankResponseSchema](docs/ActionItemBankResponseSchema.md)
- [ActiveEventSchema](docs/ActiveEventSchema.md)
- [AddAccountSchema](docs/AddAccountSchema.md)
- [AddCharacterSchema](docs/AddCharacterSchema.md)
- [AnnouncementSchema](docs/AnnouncementSchema.md)
- [BankItemSchema](docs/BankItemSchema.md)
- [BlockedHitsSchema](docs/BlockedHitsSchema.md)
- [ChangePassword](docs/ChangePassword.md)
- [CharacterFightDataSchema](docs/CharacterFightDataSchema.md)
- [CharacterFightResponseSchema](docs/CharacterFightResponseSchema.md)
- [CharacterMovementDataSchema](docs/CharacterMovementDataSchema.md)
- [CharacterMovementResponseSchema](docs/CharacterMovementResponseSchema.md)
- [CharacterResponseSchema](docs/CharacterResponseSchema.md)
- [CharacterSchema](docs/CharacterSchema.md)
- [CooldownSchema](docs/CooldownSchema.md)
- [CraftSchema](docs/CraftSchema.md)
- [CraftingSchema](docs/CraftingSchema.md)
- [DataPageActiveEventSchema](docs/DataPageActiveEventSchema.md)
- [DataPageCharacterSchema](docs/DataPageCharacterSchema.md)
- [DataPageGEItemSchema](docs/DataPageGEItemSchema.md)
- [DataPageItemSchema](docs/DataPageItemSchema.md)
- [DataPageLogSchema](docs/DataPageLogSchema.md)
- [DataPageMapSchema](docs/DataPageMapSchema.md)
- [DataPageMonsterSchema](docs/DataPageMonsterSchema.md)
- [DataPageResourceSchema](docs/DataPageResourceSchema.md)
- [DataPageSimpleItemSchema](docs/DataPageSimpleItemSchema.md)
- [DeleteCharacterSchema](docs/DeleteCharacterSchema.md)
- [DeleteItemResponseSchema](docs/DeleteItemResponseSchema.md)
- [DeleteItemSchema](docs/DeleteItemSchema.md)
- [DepositWithdrawGoldSchema](docs/DepositWithdrawGoldSchema.md)
- [DestinationSchema](docs/DestinationSchema.md)
- [DropRateSchema](docs/DropRateSchema.md)
- [DropSchema](docs/DropSchema.md)
- [EquipRequestSchema](docs/EquipRequestSchema.md)
- [EquipSchema](docs/EquipSchema.md)
- [EquipmentResponseSchema](docs/EquipmentResponseSchema.md)
- [FightSchema](docs/FightSchema.md)
- [GEItemResponseSchema](docs/GEItemResponseSchema.md)
- [GEItemSchema](docs/GEItemSchema.md)
- [GETransactionItemSchema](docs/GETransactionItemSchema.md)
- [GETransactionListSchema](docs/GETransactionListSchema.md)
- [GETransactionResponseSchema](docs/GETransactionResponseSchema.md)
- [GETransactionSchema](docs/GETransactionSchema.md)
- [GoldBankResponseSchema](docs/GoldBankResponseSchema.md)
- [GoldResponseSchema](docs/GoldResponseSchema.md)
- [GoldSchema](docs/GoldSchema.md)
- [GoldTransactionSchema](docs/GoldTransactionSchema.md)
- [HTTPValidationError](docs/HTTPValidationError.md)
- [InventorySlot](docs/InventorySlot.md)
- [ItemEffectSchema](docs/ItemEffectSchema.md)
- [ItemResponseSchema](docs/ItemResponseSchema.md)
- [ItemSchema](docs/ItemSchema.md)
- [LogSchema](docs/LogSchema.md)
- [MapContentSchema](docs/MapContentSchema.md)
- [MapResponseSchema](docs/MapResponseSchema.md)
- [MapSchema](docs/MapSchema.md)
- [MonsterResponseSchema](docs/MonsterResponseSchema.md)
- [MonsterSchema](docs/MonsterSchema.md)
- [MyCharactersListSchema](docs/MyCharactersListSchema.md)
- [RecyclingDataSchema](docs/RecyclingDataSchema.md)
- [RecyclingItemsSchema](docs/RecyclingItemsSchema.md)
- [RecyclingResponseSchema](docs/RecyclingResponseSchema.md)
- [RecyclingSchema](docs/RecyclingSchema.md)
- [ResourceResponseSchema](docs/ResourceResponseSchema.md)
- [ResourceSchema](docs/ResourceSchema.md)
- [ResponseSchema](docs/ResponseSchema.md)
- [SimpleItemSchema](docs/SimpleItemSchema.md)
- [SingleItemSchema](docs/SingleItemSchema.md)
- [SkillDataSchema](docs/SkillDataSchema.md)
- [SkillInfoSchema](docs/SkillInfoSchema.md)
- [SkillResponseSchema](docs/SkillResponseSchema.md)
- [StatusResponseSchema](docs/StatusResponseSchema.md)
- [StatusSchema](docs/StatusSchema.md)
- [TaskDataSchema](docs/TaskDataSchema.md)
- [TaskResponseSchema](docs/TaskResponseSchema.md)
- [TaskRewardDataSchema](docs/TaskRewardDataSchema.md)
- [TaskRewardResponseSchema](docs/TaskRewardResponseSchema.md)
- [TaskRewardSchema](docs/TaskRewardSchema.md)
- [TaskSchema](docs/TaskSchema.md)
- [TokenResponseSchema](docs/TokenResponseSchema.md)
- [UnequipSchema](docs/UnequipSchema.md)
- [ValidationError](docs/ValidationError.md)
- [ValidationErrorLocInner](docs/ValidationErrorLocInner.md)

<a id="documentation-for-authorization"></a>

## Documentation For Authorization

Authentication schemes defined for the API:
<a id="JWTBearer"></a>

### JWTBearer

- **Type**: Bearer authentication

<a id="HTTPBasic"></a>

### HTTPBasic

- **Type**: HTTP basic authentication

## Author
